package Row;
use ObjStore;
use base 'ObjStore::HV';

sub _is_corrupted {0}

# Gee, that was hard.

1;
